/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { IConsumer, IQueuedMessage } from "@fluidframework/server-services-core";
import * as kafka from "kafka-node";
/**
 * Kafka consumer using the kafka-node library
 * @internal
 */
export declare class KafkaNodeConsumer implements IConsumer {
    private readonly clientOptions;
    readonly groupId: string;
    readonly topic: string;
    private readonly topicPartitions?;
    private readonly topicReplicationFactor?;
    private readonly reconnectDelay;
    private client;
    private consumerGroup;
    private readonly events;
    private readonly zookeeper?;
    constructor(clientOptions: kafka.KafkaClientOptions, clientId: string, groupId: string, topic: string, zookeeperEndpoint?: string, topicPartitions?: number | undefined, topicReplicationFactor?: number | undefined, reconnectDelay?: number);
    isConnected(): boolean;
    /**
     * Returns the offset of the latest consumsed message
     */
    getLatestMessageOffset(partitionId: number): number | undefined;
    commitCheckpoint(partitionId: number, queuedMessage: IQueuedMessage): Promise<void>;
    close(): Promise<void>;
    on(event: string, listener: (...args: any[]) => void): this;
    once(event: string, listener: (...args: any[]) => void): this;
    pause(): Promise<void>;
    resume(): Promise<void>;
    private connect;
    private getPartitions;
}
//# sourceMappingURL=kafkaNodeConsumer.d.ts.map